@@ -41,11 +41,12 @@ class ApplicationModel(AppModel):
     id: UUID
     mode: str
     domain: str
-    cleint_id: str
+    client_id: str
     client_secret: str
     client_scope: str
     redirect_uri: str
     response_type: str
+    grant_type: str
     is_active: bool
     project: ProjectModel
     modules: Optional[List[ModuleModel]]
\ No newline at end of file
