@@ -1,4 +1,4 @@
-
+from typing import Optional
 from pydantic import BaseModel
 
 
@@ -14,6 +14,6 @@ class UserAgentModel(BaseModel):
     os_name: str
     os_version: str
     device_name: str
-    device_brand: str
-    device_model: str
+    device_brand: Optional[str]
+    device_model: Optional[str]
     
