@@ -8,6 +8,7 @@ from django.http import HttpRequest
 from nkunyim_util.caches.account_cache import AccountCache
 from nkunyim_util.models.account_model import AccountModel, MenuModel, NavModel
 from nkunyim_util.api.nkunyim_api_client import NkunyimApiClient
+from nkunyim_util.models.message_model import MessageLevel, MessageModel
 from nkunyim_util.models.user_model import RoleModel
 from nkunyim_util.services.session_service import SessionService
 
@@ -21,6 +22,7 @@ class AccountService:
         self.cache = AccountCache(key=f"acc.{session_key}")
         self.application_id = str(application_id)
         self.req = req
+        self.messages: list[MessageModel] = []
 
 
     def _build_from_menus(self, menus: List[dict]) -> tuple[dict[str, str], List[NavModel]] :
@@ -76,6 +78,7 @@ class AccountService:
             response = client.get(path=f"/accounts/menus/?application_id={self.application_id}")
             return dict(response.json()) if response.ok else None
         except:
+            self.messages.append(MessageModel(level=MessageLevel.WARNING, message="Failed to retrieve account data from API."))
             return None
         
         
