@@ -1,7 +1,7 @@
 from django.http import HttpRequest
 
 from nkunyim_util.models.page_model import PageModel
-
+from nkunyim_util.models.constants import MODULE_PAGE_PERMISSIONS, MODULE_PAGE_PERMISSIONS_EXT
 
 class PageService:
     
@@ -28,7 +28,9 @@ class PageService:
             "path": path,
             "dirs": dirs,
             "node": node,
-            "name": f"{node.title()}Page"
+            "name": f"{node.title()}Page",
+            "perms": MODULE_PAGE_PERMISSIONS,
+            "perms_ext": MODULE_PAGE_PERMISSIONS_EXT,
         }
         
         return PageModel(**data)
\ No newline at end of file
