@@ -5,7 +5,6 @@ from django.dispatch import Signal
 # Nation signal
 nation_data_updated = Signal()
 
-
 # Application signal
 app_data_updated = Signal()
 
@@ -13,4 +12,10 @@ app_data_updated = Signal()
 user_data_updated = Signal()
 
 # Access signal
-access_data_updated = Signal()
\ No newline at end of file
+access_data_updated = Signal()
+
+# Token signal
+token_data_updated = Signal()
+
+# UserInfo signal
+userinfo_data_updated = Signal()
\ No newline at end of file
