@@ -3,6 +3,7 @@ from typing import Optional
 from django.conf import settings
 from django.http import HttpRequest
 
+from nkunyim_util.models.message_model import MessageModel, MessageLevel
 from nkunyim_util.models.user_model import UserModel
 from nkunyim_util.api.nkunyim_api_client import NkunyimApiClient
 from nkunyim_util.services.session_service import SessionService
@@ -12,6 +13,7 @@ class UserService:
     
     def __init__(self, req: HttpRequest) -> None:
         self.req = req
+        self.messages: list[MessageModel] = []
         
         
     def api(self, token: str) -> Optional[UserModel]:
@@ -31,9 +33,11 @@ class UserService:
             response = client.get(path="/api/users/me")
             user_data = response.json() if response.ok else None  
             if not user_data:
+                self.messages.append(MessageModel(level=MessageLevel.WARNING, message="Failed to retrieve user data from API."))
                 return None
             
             if not ('id' in user_data and user_data['id']):
+                self.messages.append(MessageModel(level=MessageLevel.WARNING, message="Invalid user data received from API."))
                 return None
             
             user_model = UserModel(**user_data)
@@ -44,5 +48,6 @@ class UserService:
             
             return user_model
         except:
+            self.messages.append(MessageModel(level=MessageLevel.ERROR, message="Failed to retrieve user data from API."))
             return None 
         
